Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2941)

Unified Diff: chrome/browser/ssl_client_certificate_selector.h

Issue 9384014: Remove knowledge about SSLClientAuthHandler from chrome. Instead a callback is given to the embed... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: review comments+sync Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ssl_client_certificate_selector.h
===================================================================
--- chrome/browser/ssl_client_certificate_selector.h (revision 121706)
+++ chrome/browser/ssl_client_certificate_selector.h (working copy)
@@ -6,24 +6,28 @@
#define CHROME_BROWSER_SSL_CLIENT_CERTIFICATE_SELECTOR_H_
#pragma once
-class SSLClientAuthHandler;
+#include "base/callback_forward.h"
+
class TabContentsWrapper;
namespace net {
+class HttpNetworkSession;
class SSLCertRequestInfo;
+class X509Certificate;
}
namespace browser {
// Opens a constrained SSL client certificate selection dialog under |parent|,
// offering certificates from |cert_request_info|. When the user has made a
// selection, the dialog will report back to |delegate|. |delegate| is notified
// when the dialog closes in call cases; if the user cancels the dialog, we call
// with a NULL certificate.
void ShowSSLClientCertificateSelector(
TabContentsWrapper* wrapper,
+ const net::HttpNetworkSession* network_session,
net::SSLCertRequestInfo* cert_request_info,
- SSLClientAuthHandler* delegate);
+ const base::Callback<void(net::X509Certificate*)>& callback);
// Same as above, but doesn't check the UseMoreWebUI flag. It just calls the
// native implementation. This lets us have both the WebUI implementation and
@@ -31,8 +35,9 @@
// a run-time flag.
void ShowNativeSSLClientCertificateSelector(
TabContentsWrapper* wrapper,
+ const net::HttpNetworkSession* network_session,
net::SSLCertRequestInfo* cert_request_info,
- SSLClientAuthHandler* delegate);
+ const base::Callback<void(net::X509Certificate*)>& callback);
} // namespace browser
« no previous file with comments | « chrome/browser/ssl/ssl_client_auth_requestor_mock.h ('k') | chrome/browser/tab_contents/tab_contents_ssl_helper.h » ('j') | no next file with comments »
@@ -6,24 +6,28 @@
// Opens a constrained SSL client certificate selection dialog under |parent|,
// offering certificates from |cert_request_info|. When the user has made a
-// selection, the dialog will report back to |delegate|. |delegate| is notified
+// selection, the dialog will report back to |callback|. |callback| is notified
// when the dialog closes in call cases; if the user cancels the dialog, we call
// with a NULL certificate.

Powered by Google App Engine
This is Rietveld 408576698